/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Entwicklung
 * Adolf-Dambach-Strae
 * D-76571 Gaggenau
 * Phone: +49 (0)7225-64-0
 * Fax: +49 (0)7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.stau;

import java.util.ArrayList;
import java.util.List;

import de.bsvrz.dav.daf.main.ClientDavConnection;
import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Kommentar 
 *
 * @version $Revision: 1.1 $ / $Date: 2015/09/02 12:49:18 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class ParameterStauFsOrientiert
{
	/**
	 * Pid der Attributgruppe.
	 */
	private String m_pidAtg = "atg.sswSbaUeStauFsOrientiert";
	/**
	 * Grenzwert Gte.
	 */
	private float m_guete;
	/**
	 * Grenzwerte Belastung fr 1 Fahrstreifen.
	 */
	private Grenzwerte1Bis2Fs m_fahrstreifen1;
	/**
	 * Grenzwerte Belastung fr 2 Fahrstreifen.
	 */
	private Grenzwerte1Bis2Fs m_fahrstreifen2;
	/**
	 * Grenzwerte Belastung fr 3 Fahrstreifen.
	 */
	private Grenzwerte3Bis5Fs m_fahrstreifen3;
	/**
	 * Grenzwerte Belastung fr 4 Fahrstreifen.
	 */
	private Grenzwerte3Bis5Fs m_fahrstreifen4;
	/**
	 * Grenzwerte Belastung fr 5 Fahrstreifen.
	 */
	private Grenzwerte3Bis5Fs m_fahrstreifen5;
	/**
	 * Referenz auf einen Anzeigequerschnitt.
	 */
//	private SystemObject m_anzeigeQuerschnitt;
	/**
	 * Liste mit Referenzen auf Anzeigen.
	 */
	private List<SystemObject> m_anzeige;
	/**
	 * Einschaltgrenzwerte Geschindigkeit.
	 */
	private List<GrenzwerteGeschwindigkeit> m_vEin;
	/**
	 * Ausschaltgrenzwerte Geschindigkeit.
	 */
	private List<GrenzwerteGeschwindigkeit> m_vAus;
	
	/**
	 * Default-Konstruktor der Klasse.
	 */
	public ParameterStauFsOrientiert()
	{
		
	}
	/**
	 * Konstruktor der Klasse mit bernahme der Daten.
	 * @param rdata Datensatz der Parameter.
	 */
	public ParameterStauFsOrientiert(ResultData rdata)
	{
		setdaten(rdata);
	}
	
	/**
	 * bernahme des bergebenen Datensatzes in die interne Struktur.
	 * 
	 * @param rdata Datensatz der Parameter.
	 */
	public void setdaten(ResultData rdata)
	{
		if (rdata != null)
		{
			Data data = rdata.getData();
			if (data != null)
			{
				if (m_fahrstreifen1 == null)
				{
					m_fahrstreifen1 = new Grenzwerte1Bis2Fs();
				}
				
				m_fahrstreifen1.setQ_f(data.getItem("1Fahrstreifen").getUnscaledValue("Q_F").intValue());

				if (m_fahrstreifen2 == null)
				{
					m_fahrstreifen2 = new Grenzwerte1Bis2Fs();
				}
				
				m_fahrstreifen2.setQ_f(data.getItem("2Fahrstreifen").getUnscaledValue("Q_F").intValue());

				if (m_fahrstreifen3 == null)
				{
					m_fahrstreifen3 = new Grenzwerte3Bis5Fs();
				}
				
				m_fahrstreifen3.setQ_f(data.getItem("3Fahrstreifen").getUnscaledValue("Q_F").intValue());
				m_fahrstreifen3.setQ_g(data.getItem("3Fahrstreifen").getUnscaledValue("Q_G").intValue());
				m_fahrstreifen3.setX1((int)data.getItem("3Fahrstreifen").getUnscaledValue("X1").longValue());
				m_fahrstreifen3.setX2((int)data.getItem("3Fahrstreifen").getUnscaledValue("X2").longValue());
				m_fahrstreifen3.setX3((int)data.getItem("3Fahrstreifen").getUnscaledValue("X3").longValue());
			
				if (m_fahrstreifen4 == null)
				{
					m_fahrstreifen4 = new Grenzwerte3Bis5Fs();
				}
				
				m_fahrstreifen4.setQ_f(data.getItem("4Fahrstreifen").getUnscaledValue("Q_F").intValue());
				m_fahrstreifen4.setQ_g(data.getItem("4Fahrstreifen").getUnscaledValue("Q_G").intValue());
				m_fahrstreifen4.setX1((int)data.getItem("4Fahrstreifen").getUnscaledValue("X1").longValue());
				m_fahrstreifen4.setX2((int)data.getItem("4Fahrstreifen").getUnscaledValue("X2").longValue());
				m_fahrstreifen4.setX3((int)data.getItem("4Fahrstreifen").getUnscaledValue("X3").longValue());

				if (m_fahrstreifen5 == null)
				{
					m_fahrstreifen5 = new Grenzwerte3Bis5Fs();
				}
				
				m_fahrstreifen5.setQ_f(data.getItem("5Fahrstreifen").getUnscaledValue("Q_F").intValue());
				m_fahrstreifen5.setQ_g(data.getItem("5Fahrstreifen").getUnscaledValue("Q_G").intValue());
				m_fahrstreifen5.setX1((int)data.getItem("5Fahrstreifen").getUnscaledValue("X1").longValue());
				m_fahrstreifen5.setX2((int)data.getItem("5Fahrstreifen").getUnscaledValue("X2").longValue());
				m_fahrstreifen5.setX3((int)data.getItem("5Fahrstreifen").getUnscaledValue("X3").longValue());

				if (m_vEin == null)
				{
					m_vEin = new ArrayList<ParameterStauFsOrientiert.GrenzwerteGeschwindigkeit>();
				}
				else
				{
					m_vEin.clear();
				}
				
				for (int i = 0; i < data.getArray("v_ein").getLength(); i++)
				{
					m_vEin.add(new GrenzwerteGeschwindigkeit(data.getArray("v_ein").getItem(i)));					
				}

				if (m_vAus == null)
				{
					m_vAus = new ArrayList<ParameterStauFsOrientiert.GrenzwerteGeschwindigkeit>();
				}
				else
				{
					m_vAus.clear();
				}
				
				for (int i = 0; i < data.getArray("v_aus").getLength(); i++)
				{
					m_vAus.add(new GrenzwerteGeschwindigkeit(data.getArray("v_aus").getItem(i)));					
				}
				
				if (m_anzeige == null)
				{
					m_anzeige = new ArrayList<SystemObject>();
				}
				else
				{
					m_anzeige.clear();
				}
				
				for (int i = 0; i < data.getArray("Anzeige").getLength(); i++)
				{
					m_anzeige.add(data.getArray("Anzeige").getReferenceValue(i).getSystemObject());
				}
				
				m_guete = data.getScaledValue("Gte").floatValue();				
			}
			else
			{
				m_fahrstreifen1 = new Grenzwerte1Bis2Fs();
				m_fahrstreifen2 = new Grenzwerte1Bis2Fs();
				m_fahrstreifen3 = new Grenzwerte3Bis5Fs();
				m_fahrstreifen4 = new Grenzwerte3Bis5Fs();
				m_fahrstreifen5 = new Grenzwerte3Bis5Fs();
				
				m_vEin = new ArrayList<ParameterStauFsOrientiert.GrenzwerteGeschwindigkeit>();
				m_vAus = new ArrayList<ParameterStauFsOrientiert.GrenzwerteGeschwindigkeit>();

				m_anzeige = new ArrayList<SystemObject>();
				m_guete = 0;
			}
		}
	}

	/**
	 * Erzeugt einen Datensatz der Attributgruppe <code>atg.sswSbaUeStauFsOrientiert</code> mit
	 * den Daten der internen Struktur.
	 * 
	 * @param connection Aktuelle Verbindung zum Datenverteiler.
	 * @return erzeugter Datensatz.
	 */
	public Data erzeugeDatensatz(ClientDavConnection connection)
	{
		DataModel dm = connection.getDataModel();		
		Data dataNeu = connection.createData(dm.getAttributeGroup(m_pidAtg));

		if (dataNeu != null)
		{	
			dataNeu.getItem("1Fahrstreifen").getUnscaledValue("Q_F").set(m_fahrstreifen1.getQ_f());

			dataNeu.getItem("2Fahrstreifen").getUnscaledValue("Q_F").set(m_fahrstreifen2.getQ_f());

			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("Q_F").set(m_fahrstreifen3.getQ_f());
			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("Q_G").set(m_fahrstreifen3.getQ_g());
			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("X1").set(m_fahrstreifen3.getX1());
			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("X2").set(m_fahrstreifen3.getX2());
			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("X3").set(m_fahrstreifen3.getX3());

			dataNeu.getItem("4Fahrstreifen").getUnscaledValue("Q_F").set(m_fahrstreifen4.getQ_f());
			dataNeu.getItem("4Fahrstreifen").getUnscaledValue("Q_G").set(m_fahrstreifen4.getQ_g());
			dataNeu.getItem("4Fahrstreifen").getUnscaledValue("X1").set(m_fahrstreifen4.getX1());
			dataNeu.getItem("4Fahrstreifen").getUnscaledValue("X2").set(m_fahrstreifen4.getX2());
			dataNeu.getItem("4Fahrstreifen").getUnscaledValue("X3").set(m_fahrstreifen4.getX3());

			dataNeu.getItem("5Fahrstreifen").getUnscaledValue("Q_F").set(m_fahrstreifen5.getQ_f());
			dataNeu.getItem("5Fahrstreifen").getUnscaledValue("Q_G").set(m_fahrstreifen5.getQ_g());
			dataNeu.getItem("5Fahrstreifen").getUnscaledValue("X1").set(m_fahrstreifen5.getX1());
			dataNeu.getItem("5Fahrstreifen").getUnscaledValue("X2").set(m_fahrstreifen5.getX2());
			dataNeu.getItem("5Fahrstreifen").getUnscaledValue("X3").set(m_fahrstreifen5.getX3());

			dataNeu.getArray("v_ein").setLength(0);
			if (m_vEin != null)
			{
				for (int i = 0; i < m_vEin.size(); i++)
				{
					dataNeu.getArray("v_ein").setLength(i+1);
					
					Data element = dataNeu.getArray("v_ein").getItem(i);
					
					GrenzwerteGeschwindigkeit gw = m_vEin.get(i);
					
					element.getReferenceValue("aktuelleAnzeige").setSystemObject(gw.getAktuelleAnzeige());
					element.getUnscaledValue("FS1").set(gw.getFs1());
					element.getUnscaledValue("FS2").set(gw.getFs2());
					element.getUnscaledValue("FS3").set(gw.getFs3());
					element.getUnscaledValue("FS4").set(gw.getFs4());
					element.getUnscaledValue("FS5").set(gw.getFs5());					
				}
			}

			dataNeu.getArray("v_aus").setLength(0);
			if (m_vAus != null)
			{
				for (int i = 0; i < m_vAus.size(); i++)
				{
					dataNeu.getArray("v_aus").setLength(i+1);
					
					Data element = dataNeu.getArray("v_aus").getItem(i);
					
					GrenzwerteGeschwindigkeit gw = m_vAus.get(i);
					
					element.getReferenceValue("aktuelleAnzeige").setSystemObject(gw.getAktuelleAnzeige());
					element.getUnscaledValue("FS1").set(gw.getFs1());
					element.getUnscaledValue("FS2").set(gw.getFs2());
					element.getUnscaledValue("FS3").set(gw.getFs3());
					element.getUnscaledValue("FS4").set(gw.getFs4());
					element.getUnscaledValue("FS5").set(gw.getFs5());					
				}
			}

			dataNeu.getArray("Anzeige").setLength(0);
			if (m_anzeige != null)
			{
				for (int i = 0; i < m_anzeige.size(); i++)
				{
					dataNeu.getArray("Anzeige").setLength(i+1);
					dataNeu.getArray("Anzeige").getReferenceValue(i).setSystemObject(m_anzeige.get(i));
				}
			}

			dataNeu.getScaledValue("Gte").set(m_guete);
			
			return dataNeu;
		}
		
		return null;
	}

	/**
	 * Gibt fr die bergebene Anzahl Fahrstreifen den entsprechenden Datensatz zurck.
	 * 
	 * @param anzFs Anzahl der Fahrstreifen.
	 * @return Parameterversorgung der bergebenen Anzahl von Fahrstreifen.
	 */
	public Grenzwerte1Bis2Fs getGrenzwerte1Bis2Fs(int anzFs)
	{
		switch (anzFs)
		{
			case 1:
			{				
				return m_fahrstreifen1;
			}
			case 2:
			{				
				return m_fahrstreifen2;
			}
		}
		return null;
	}
	/**
	 * Gibt fr die bergebene Anzahl Fahrstreifen den entsprechenden Datensatz zurck.
	 * 
	 * @param anzFs Anzahl der Fahrstreifen.
	 * @return Parameterversorgung der bergebenen Anzahl von Fahrstreifen.
	 */
	public Grenzwerte3Bis5Fs getGrenzwerte3Bis5Fs(int anzFs)
	{
		switch (anzFs)
		{
			case 3:
			{				
				return m_fahrstreifen3;
			}
			case 4:
			{				
				return m_fahrstreifen4;
			}
			case 5:
			{				
				return m_fahrstreifen5;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Schwellwert v_ein fr den gegebenen Anzeigeninhalt und Fahrspurindex zurck.
	 * Ist kein Schwellwert versorgt, wird 0 zurckgegeben.
	 *  
	 * @param anzeigeInhalt PID Anzeigeinhalt.
	 * @param indexFs Index der Fahrspur von rechts aus.
	 * @return Schwellwert oder 0.
	 */
	public int getSchwellwertVein(SystemObject anzeigeInhalt, int indexFs)
	{
		if ((m_vEin != null) && (!m_vEin.isEmpty()))
		{
			for (int i = 0; i < m_vEin.size(); i++)
			{
				if (m_vEin.get(i).getAktuelleAnzeige().equals(anzeigeInhalt))
				{
					switch (indexFs)
					{
						case 0:
						{
							return m_vEin.get(i).getFs1();
						}
						case 1:
						{
							return m_vEin.get(i).getFs2();
						}
						case 2:
						{
							return m_vEin.get(i).getFs3();
						}
						case 3:
						{
							return m_vEin.get(i).getFs4();
						}
						case 4:
						{
							return m_vEin.get(i).getFs5();
						}
					}
				}
			}
		}
		return 0;
	}

	/**
	 * Gibt den Schwellwert v_aus fr den gegebenen Anzeigeninhalt und Fahrspurindex zurck.
	 * Ist kein Schwellwert versorgt, wird 0 zurckgegeben.
	 *  
	 * @param anzeigeInhalt PID Anzeigeinhalt.
	 * @param indexFs Index der Fahrspur von rechts aus.
	 * @return Schwellwert oder 0.
	 */
	public int getSchwellwertVaus(SystemObject anzeigeInhalt, int indexFs)
	{
		if ((m_vAus != null) && (!m_vAus.isEmpty()))
		{
			for (int i = 0; i < m_vAus.size(); i++)
			{
				if (m_vAus.get(i).getAktuelleAnzeige().equals(anzeigeInhalt))
				{
					switch (indexFs)
					{
						case 0:
						{
							return m_vAus.get(i).getFs1();
						}
						case 1:
						{
							return m_vAus.get(i).getFs2();
						}
						case 2:
						{
							return m_vAus.get(i).getFs3();
						}
						case 3:
						{
							return m_vAus.get(i).getFs4();
						}
						case 4:
						{
							return m_vAus.get(i).getFs5();
						}
					}
				}
			}
		}
		return 0;
	}

	/**
	 * Gibt den Wert der Variable m_guete zurck.
	 *
	 * @return Wert der Variable m_guete.
	 */
	public float getGuete()
	{
		return m_guete;
	}
	/**
	 * Setzt den Wert der Variable m_guete.
	 *
	 * @param guete zu setzender Wert der Variable m_guete.
	 */
	public void setGuete(float guete)
	{
		m_guete = guete;
	}

	/**
	 * Gibt den Wert der Variable m_fahrstreifen1 zurck.
	 *
	 * @return Wert der Variable m_fahrstreifen1.
	 */
	public Grenzwerte1Bis2Fs getFahrstreifen1()
	{
		return m_fahrstreifen1;
	}
	/**
	 * Setzt den Wert der Variable m_fahrstreifen1.
	 *
	 * @param fahrstreifen1 zu setzender Wert der Variable m_fahrstreifen1.
	 */
	public void setFahrstreifen1(Grenzwerte1Bis2Fs fahrstreifen1)
	{
		m_fahrstreifen1 = fahrstreifen1;
	}
	/**
	 * Gibt den Wert der Variable m_fahrstreifen2 zurck.
	 *
	 * @return Wert der Variable m_fahrstreifen2.
	 */
	public Grenzwerte1Bis2Fs getFahrstreifen2()
	{
		return m_fahrstreifen2;
	}
	/**
	 * Setzt den Wert der Variable m_fahrstreifen2.
	 *
	 * @param fahrstreifen2 zu setzender Wert der Variable m_fahrstreifen2.
	 */
	public void setFahrstreifen2(Grenzwerte1Bis2Fs fahrstreifen2)
	{
		m_fahrstreifen2 = fahrstreifen2;
	}
	/**
	 * Gibt den Wert der Variable m_fahrstreifen3 zurck.
	 *
	 * @return Wert der Variable m_fahrstreifen3.
	 */
	public Grenzwerte3Bis5Fs getFahrstreifen3()
	{
		return m_fahrstreifen3;
	}
	/**
	 * Setzt den Wert der Variable m_fahrstreifen3.
	 *
	 * @param fahrstreifen3 zu setzender Wert der Variable m_fahrstreifen3.
	 */
	public void setFahrstreifen3(Grenzwerte3Bis5Fs fahrstreifen3)
	{
		m_fahrstreifen3 = fahrstreifen3;
	}
	/**
	 * Gibt den Wert der Variable m_fahrstreifen4 zurck.
	 *
	 * @return Wert der Variable m_fahrstreifen4.
	 */
	public Grenzwerte3Bis5Fs getFahrstreifen4()
	{
		return m_fahrstreifen4;
	}
	/**
	 * Setzt den Wert der Variable m_fahrstreifen4.
	 *
	 * @param fahrstreifen4 zu setzender Wert der Variable m_fahrstreifen4.
	 */
	public void setFahrstreifen4(Grenzwerte3Bis5Fs fahrstreifen4)
	{
		m_fahrstreifen4 = fahrstreifen4;
	}
	/**
	 * Gibt den Wert der Variable m_fahrstreifen5 zurck.
	 *
	 * @return Wert der Variable m_fahrstreifen5.
	 */
	public Grenzwerte3Bis5Fs getFahrstreifen5()
	{
		return m_fahrstreifen5;
	}
	/**
	 * Setzt den Wert der Variable m_fahrstreifen5.
	 *
	 * @param fahrstreifen5 zu setzender Wert der Variable m_fahrstreifen5.
	 */
	public void setFahrstreifen5(Grenzwerte3Bis5Fs fahrstreifen5)
	{
		m_fahrstreifen5 = fahrstreifen5;
	}
	
	/**
	 * Gibt den Wert der Variable m_anzeige zurck.
	 *
	 * @return Wert der Variable m_anzeige.
	 */
	public List<SystemObject> getAnzeige()
	{
		return m_anzeige;
	}
	/**
	 * Gibt den Wert der Variable m_anzeige fr den gegebenen Index zurck.
	 * Ist der Index nicht vorhanden, wird <code>null</code> zurckgegeben.
	 *
	 * @return Wert der Variable m_anzeige fr den Index oder <code>null</code>.
	 */
	public SystemObject getAnzeigeIndex(int index)
	{
		if (m_anzeige != null)
		{
			if (m_anzeige.size() > index)
			{
				return m_anzeige.get(index);
			}
		}
		return null;
	}
	/**
	 * Setzt den Wert der Variable m_anzeige.
	 *
	 * @param anzeige zu setzender Wert der Variable m_anzeige.
	 */
	public void setAnzeige(List<SystemObject> anzeige)
	{
		m_anzeige = anzeige;
	}
	/**
	 * Gibt den Wert der Variable m_vEin zurck.
	 *
	 * @return Wert der Variable m_vEin.
	 */
	public List<GrenzwerteGeschwindigkeit> getvEin()
	{
		if (m_vEin == null)
			m_vEin = new ArrayList<ParameterStauFsOrientiert.GrenzwerteGeschwindigkeit>();
		
		return m_vEin;
	}
	/**
	 * Gibt den Wert der Variable m_vAus zurck.
	 *
	 * @return Wert der Variable m_vAus.
	 */
	public List<GrenzwerteGeschwindigkeit> getvAus()
	{
		if (m_vAus == null)
			m_vAus = new ArrayList<ParameterStauFsOrientiert.GrenzwerteGeschwindigkeit>();

		return m_vAus;
	}

	/**
	 * 
	 * Innere Klasse zum Speichern der Grenzwerte fr 1 bis 2 Fahrstreifen. 
	 *
	 * @version $Revision: 1.1 $ / $Date: 2015/09/02 12:49:18 $ / ($Author: Asal $)
	 *
	 * @author Swarco Traffic Systems GmbH
	 * @author Rolf Asal
	 *
	 */
	public class Grenzwerte1Bis2Fs
	{
		/**
		 * Grenzwert freier Verkehr in PkwE/h.
		 */
		private int m_q_f;
		
		/**
		 * Default-Konstruktor der Klasse.
		 */
		public Grenzwerte1Bis2Fs()
		{
			
		}

		/**
		 * Gibt den Wert der Variable m_q_f zurck.
		 *
		 * @return Wert der Variable m_q_f.
		 */
		public int getQ_f()
		{
			return m_q_f;
		}

		/**
		 * Setzt den Wert der Variable m_q_f.
		 *
		 * @param q_f zu setzender Wert der Variable m_q_f.
		 */
		public void setQ_f(int q_f)
		{
			m_q_f = q_f;
		}

		/* (non-Javadoc)
		 * @see java.lang.Object#toString()
		 */
		@Override
		public String toString()
		{
			return "Grenzwerte1Bis2Fs [m_q_f=" + m_q_f + "]";
		}
		
	}
	/**
	 * 
	 * Innere Klasse zum Speichern der Grenzwerte fr 3 bis 5 Fahrstreifen. 
	 *
	 * @version $Revision: 1.1 $ / $Date: 2015/09/02 12:49:18 $ / ($Author: Asal $)
	 *
	 * @author Swarco Traffic Systems GmbH
	 * @author Rolf Asal
	 *
	 */
	public class Grenzwerte3Bis5Fs
	{
		/**
		 * Grenzwert freier Verkehr in PkwE/h.
		 */
		private int m_q_f;
		/**
		 * Grenzwert gebundener Verkehr in PkwE/h.
		 */
		private int m_q_g;
		/**
		 * Anzahl Geschwindigkeitsschwellwerte unter-/berschritten fr Kriterium 1.
		 */
		private int m_x1;
		/**
		 * Anzahl Geschwindigkeitsschwellwerte unter-/berschritten fr Kriterium 2.
		 */
		private int m_x2;
		/**
		 * Anzahl Geschwindigkeitsschwellwerte unter-/berschritten fr Kriterium 3.
		 */
		private int m_x3;
		
		/**
		 * Default-Konstruktor der Klasse.
		 */
		public Grenzwerte3Bis5Fs()
		{
			
		}

		/**
		 * Gibt den Wert der Variable m_q_f zurck.
		 *
		 * @return Wert der Variable m_q_f.
		 */
		public int getQ_f()
		{
			return m_q_f;
		}

		/**
		 * Setzt den Wert der Variable m_q_f.
		 *
		 * @param q_f zu setzender Wert der Variable m_q_f.
		 */
		public void setQ_f(int q_f)
		{
			m_q_f = q_f;
		}

		/**
		 * Gibt den Wert der Variable m_q_g zurck.
		 *
		 * @return Wert der Variable m_q_g.
		 */
		public int getQ_g()
		{
			return m_q_g;
		}

		/**
		 * Setzt den Wert der Variable m_q_g.
		 *
		 * @param q_g zu setzender Wert der Variable m_q_g.
		 */
		public void setQ_g(int q_g)
		{
			m_q_g = q_g;
		}

		/**
		 * Gibt den Wert der Variable m_x1 zurck.
		 *
		 * @return Wert der Variable m_x1.
		 */
		public int getX1()
		{
			return m_x1;
		}

		/**
		 * Setzt den Wert der Variable m_x1.
		 *
		 * @param x1 zu setzender Wert der Variable m_x1.
		 */
		public void setX1(int x1)
		{
			m_x1 = x1;
		}

		/**
		 * Gibt den Wert der Variable m_x2 zurck.
		 *
		 * @return Wert der Variable m_x2.
		 */
		public int getX2()
		{
			return m_x2;
		}

		/**
		 * Setzt den Wert der Variable m_x2.
		 *
		 * @param x2 zu setzender Wert der Variable m_x2.
		 */
		public void setX2(int x2)
		{
			m_x2 = x2;
		}

		/**
		 * Gibt den Wert der Variable m_x3 zurck.
		 *
		 * @return Wert der Variable m_x3.
		 */
		public int getX3()
		{
			return m_x3;
		}

		/**
		 * Setzt den Wert der Variable m_x3.
		 *
		 * @param x3 zu setzender Wert der Variable m_x3.
		 */
		public void setX3(int x3)
		{
			m_x3 = x3;
		}

		/* (non-Javadoc)
		 * @see java.lang.Object#toString()
		 */
		@Override
		public String toString()
		{
			return "Grenzwerte3Bis5Fs [m_q_f=" + m_q_f + ", m_q_g=" + m_q_g + ", m_x1=" + m_x1 + ", m_x2=" + m_x2 + ", m_x3=" + m_x3 + "]";
		}
	}
	
	/**
	 * 
	 * Innere Klasse zum Speichern der Grenzwerte Geschwindigkeit. 
	 *
	 * @version $Revision: 1.1 $ / $Date: 2015/09/02 12:49:18 $ / ($Author: Asal $)
	 *
	 * @author Swarco Traffic Systems GmbH
	 * @author Rolf Asal
	 *
	 */
	public class GrenzwerteGeschwindigkeit
	{
		/**
		 * Referenz auf einen AnzeigeInhalt.
		 */
		private SystemObject m_aktuelleAnzeige;
		/**
		 * Grenzwert Geschwindigkeit Fahrspur 1.
		 */
		private int m_fs1;
		/**
		 * Grenzwert Geschwindigkeit Fahrspur 2.
		 */
		private int m_fs2;
		/**
		 * Grenzwert Geschwindigkeit Fahrspur 3.
		 */
		private int m_fs3;
		/**
		 * Grenzwert Geschwindigkeit Fahrspur 4.
		 */
		private int m_fs4;
		/**
		 * Grenzwert Geschwindigkeit Fahrspur 5.
		 */
		private int m_fs5;
		
		/**
		 * Default-Konstruktor der Klasse.
		 */
		public GrenzwerteGeschwindigkeit()
		{
			
		}
		/**
		 * Konstruktor der Klasse mit bernahme der Daten.
		 * 
		 * @param data zu bernehmende Daten.
		 */
		public GrenzwerteGeschwindigkeit(Data data)
		{
			if (data != null)
			{
				setAktuelleAnzeige(data.getReferenceValue("aktuelleAnzeige").getSystemObject());

				setFs1(data.getUnscaledValue("FS1").intValue());
				setFs2(data.getUnscaledValue("FS2").intValue());
				setFs3(data.getUnscaledValue("FS3").intValue());
				setFs4(data.getUnscaledValue("FS4").intValue());
				setFs5(data.getUnscaledValue("FS5").intValue());
			}
		}

		/**
		 * Gibt den Wert der Variable m_aktuelleAnzeige zurck.
		 *
		 * @return Wert der Variable m_aktuelleAnzeige.
		 */
		public SystemObject getAktuelleAnzeige()
		{
			return m_aktuelleAnzeige;
		}

		/**
		 * Setzt den Wert der Variable m_aktuelleAnzeige.
		 *
		 * @param aktuelleAnzeige zu setzender Wert der Variable m_aktuelleAnzeige.
		 */
		public void setAktuelleAnzeige(SystemObject aktuelleAnzeige)
		{
			m_aktuelleAnzeige = aktuelleAnzeige;
		}

		/**
		 * Gibt den Wert der Variable m_fs1 zurck.
		 *
		 * @return Wert der Variable m_fs1.
		 */
		public int getFs1()
		{
			return m_fs1;
		}

		/**
		 * Setzt den Wert der Variable m_fs1.
		 *
		 * @param fs1 zu setzender Wert der Variable m_fs1.
		 */
		public void setFs1(int fs1)
		{
			m_fs1 = fs1;
		}

		/**
		 * Gibt den Wert der Variable m_fs2 zurck.
		 *
		 * @return Wert der Variable m_fs2.
		 */
		public int getFs2()
		{
			return m_fs2;
		}

		/**
		 * Setzt den Wert der Variable m_fs2.
		 *
		 * @param fs2 zu setzender Wert der Variable m_fs2.
		 */
		public void setFs2(int fs2)
		{
			m_fs2 = fs2;
		}

		/**
		 * Gibt den Wert der Variable m_fs3 zurck.
		 *
		 * @return Wert der Variable m_fs3.
		 */
		public int getFs3()
		{
			return m_fs3;
		}

		/**
		 * Setzt den Wert der Variable m_fs3.
		 *
		 * @param fs3 zu setzender Wert der Variable m_fs3.
		 */
		public void setFs3(int fs3)
		{
			m_fs3 = fs3;
		}

		/**
		 * Gibt den Wert der Variable m_fs4 zurck.
		 *
		 * @return Wert der Variable m_fs4.
		 */
		public int getFs4()
		{
			return m_fs4;
		}

		/**
		 * Setzt den Wert der Variable m_fs4.
		 *
		 * @param fs4 zu setzender Wert der Variable m_fs4.
		 */
		public void setFs4(int fs4)
		{
			m_fs4 = fs4;
		}

		/**
		 * Gibt den Wert der Variable m_fs5 zurck.
		 *
		 * @return Wert der Variable m_fs5.
		 */
		public int getFs5()
		{
			return m_fs5;
		}

		/**
		 * Setzt den Wert der Variable m_fs5.
		 *
		 * @param fs5 zu setzender Wert der Variable m_fs5.
		 */
		public void setFs5(int fs5)
		{
			m_fs5 = fs5;
		}

		/* (non-Javadoc)
		 * @see java.lang.Object#toString()
		 */
		@Override
		public String toString()
		{
			return "GrenzwerteGeschwindigkeit [m_aktuelleAnzeige=" + m_aktuelleAnzeige + ", m_fs1=" + m_fs1 + ", m_fs2=" + m_fs2 + ", m_fs3=" + m_fs3 + ", m_fs4=" + m_fs4 + ", m_fs5=" + m_fs5 + "]";
		}
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		return "ParameterStauFsOrientiert [m_fahrstreifen1=" + m_fahrstreifen1 + ", m_fahrstreifen2=" + m_fahrstreifen2 + ", m_fahrstreifen3=" + m_fahrstreifen3 + ", m_fahrstreifen4=" + m_fahrstreifen4
				+ ", m_fahrstreifen5=" + m_fahrstreifen5 + ", m_vEin=" + m_vEin + ", m_vAus=" + m_vAus + ", m_anzeige=" + m_anzeige + ", m_guete=" + m_guete + "]";
	}
}
