/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Entwicklung
 * Adolf-Dambach-Strae
 * D-76571 Gaggenau
 * Phone: +49 (0)7225-64-0
 * Fax: +49 (0)7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.stau;

/**
 * Klasse zum Verwalten der Staukriteriumdaten.<p>
 * Fr jedes Staukriterium werden die Zustnde "Stau" und "nichtStau" berechnet.<p>
 * 
 * Die Zustnde setzen sich jeweils aus folgenden Werten zusammen:<br>
 * - Vertrauenswrdigkeit<br>
 * - Zugehrigkeit<br>
 * - Gte<p>
 *  
 * ber Getter und Setter kann auf spezielle Werte zugegriffen werden.<br>
 * 
 * ber die Methode "init()" knnen Defaultwerte gesetzt werden.
 * 
 * @version $Revision: 1.2 $ / $Date: 2012/07/23 06:02:35 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class Staukriterium
{	
	/**
	 * Pid Messquerschnitt.
	 */
	private String m_pid;	
  /**
   * Staukriterium Zustand Stau.
   */
  private StaukriteriumWerte stau = new StaukriteriumWerte();
  /**
   * Staukriterium Zustand nicht Stau.
   */
  private StaukriteriumWerte nichtStau = new StaukriteriumWerte();
  /**
   * Staukriterium Verkehrlicher Zustand.
   */
  private boolean m_zustandVerkehrlich;
  
  /**
   * Default-Konstruktor ohne weitere Funktion.
   */
  public Staukriterium()
  {  	
  }
  
  /**
   * Initialisierung der Staukriterien auf Defaultwerte.
   */
  public void init()
  {
  	stau.vertrauenswrdigkeit = (float)0.0;
  	stau.zugehrigkeit = (float)0.0;
  	stau.gte = (float)0.0;
  
  	nichtStau.vertrauenswrdigkeit = (float)0.0;
  	nichtStau.zugehrigkeit = (float)0.0;
  	nichtStau.gte = (float)0.0;
  	
  	m_zustandVerkehrlich = false;
  }
  
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		StringBuffer string = new StringBuffer();
		
		string.append("\n        MQ : " + m_pid + 
				          "\n NichtStau : " + nichtStau +
				          "\n      Stau : " + stau +
				          "\n  ZVerkehr : " + m_zustandVerkehrlich);

		return string.toString();
	}

	/**
	 * Gibt den Wert der Variable m_zustandVerkehrlich zurck.
	 *
	 * @return Wert der Variable m_zustandVerkehrlich.
	 */
	public boolean isZustandVerkehrlich()
	{
		return m_zustandVerkehrlich;
	}

	/**
	 * Setzt den Wert der Variable m_zustandVerkehrlich.
	 *
	 * @param zustandVerkehrlich zu setzender Wert der Variable m_zustandVerkehrlich.
	 */
	public void setZustandVerkehrlich(boolean zustandVerkehrlich)
	{
		m_zustandVerkehrlich = zustandVerkehrlich;
	}

	/**
	 * Gibt die Pid zurck.
	 * @return Pid des Objekts.
	 */
	public String getPid()
	{
		return m_pid;
	}

	/**
	 * Setzt die Pid.
	 * @param pid zu setzende Pid des Objekts.
	 */
	public void setPid(String pid)
	{
		m_pid = pid;
	}
 
	/**
	 * Gibt das Staukriterium Zustand nicht Stau zurck.
	 * @return Staukriterium Zustand nicht Stau.
	 */
	public StaukriteriumWerte getNichtStau()
	{
		return nichtStau;
	}

	/**
	 * Setzt das Staukriterium Zustand nicht Stau.
	 * @param nichtStau zu setzendes Staukriterium Zustand nicht Stau.
	 */
	public void setNichtStau(StaukriteriumWerte nichtStau)
	{
		this.nichtStau = nichtStau;
	}

	/**
	 * Gibt das Staukriterium Zustand Stau zurck.
	 * @return Staukriterium Zustand Stau.
	 */
	public StaukriteriumWerte getStau()
	{
		return stau;
	}

	/**
	 * Setzt das Staukriterium Zustand Stau.
	 * @param stau zu setzendes Staukriterium Zustand Stau.
	 */
	public void setStau(StaukriteriumWerte stau)
	{
		this.stau = stau;
	}

	/**
	 * Gibt den Gteindex fr den Zustand Stau zurck.
	 * @return Gteindex fr den Zustand Stau.
	 */
	public float getGteStau()
	{
		return this.stau.gte;
	}
	
	/**
	 * Gibt den Gteindex fr den Zustand nicht Stau zurck.
	 * @return Gteindex fr den Zustand nicht Stau.
	 */
	public float getGteNichtStau()
	{
		return this.nichtStau.gte;
	}
	
	/**
	 * Setzt den Gteindex fr den Zustand Stau.
	 * @param gte zu setzender Gteindex.
	 */
	public void setGteStau(float gte)
	{
		this.stau.gte = gte;
	}
	
	/**
	 * Setzt den Gteindex fr den Zustand nicht Stau.
	 * @param gte zu setzender Gteindex.
	 */
	public void setGteNichtStau(float gte)
	{
		this.nichtStau.gte = gte;
	}

	/**
	 * Gibt die Vertrauenswrdigkeit fr den Zustand Stau zurck.
	 * @return Vertrauenswrdigkeit fr den Zustand Stau.
	 */
	public float getVertrauenswrdigkeitStau()
	{
		return this.stau.vertrauenswrdigkeit;
	}

	/**
	 * Gibt die Vertrauenswrdigkeit fr den Zustand nicht Stau zurck.
	 * @return Vertrauenswrdigkeit fr den Zustand nicht Stau.
	 */
	public float getVertrauenswrdigkeitNichtStau()
	{
		return this.nichtStau.vertrauenswrdigkeit;
	}
	
	/**
	 * Setzt die Vertrauenswrdigkeit fr den Zustand Stau
	 * @param vertrauenswrdigkeit zu setzende Vertrauenswrdigkeit.
	 */
	public void setVertrauenswrdigkeitStau(float vertrauenswrdigkeit)
	{
		this.stau.vertrauenswrdigkeit = vertrauenswrdigkeit;
	}
	
	/**
	 * Setzt die Vertrauenswrdigkeit fr den Zustand nicht Stau
	 * @param vertrauenswrdigkeit zu setzende Vertrauenswrdigkeit.
	 */
	public void setVertrauenswrdigkeitNichtStau(float vertrauenswrdigkeit)
	{
		this.nichtStau.vertrauenswrdigkeit = vertrauenswrdigkeit;
	}

	/**
	 * Gibt die Zugehrigkeit fr den Zustand Stau zurck.
	 * @return Zugehrigkeit fr den Zustand Stau.
	 */
	public float getZugehrigkeitStau()
	{
		return this.stau.zugehrigkeit;
	}

	/**
	 * Gibt die Zugehrigkeit fr den Zustand nicht Stau zurck.
	 * @return Zugehrigkeit fr den Zustand nicht Stau.
	 */
	public float getZugehrigkeitNichtStau()
	{
		return this.nichtStau.zugehrigkeit;
	}
	
	/**
	 * Setzt die Zugehrigkeit fr den Zustand Stau.
	 * @param zugehrigkeit zu setzende Zugehrigkeit.
	 */
	public void setZugehrigkeitStau(float zugehrigkeit)
	{
		this.stau.zugehrigkeit = zugehrigkeit;
	}
	
	/**
	 * Setzt die Zugehrigkeit fr den Zustand nicht Stau.
	 * @param zugehrigkeit zu setzende Zugehrigkeit.
	 */
	public void setZugehrigkeitNichtStau(float zugehrigkeit)
	{
		this.nichtStau.zugehrigkeit = zugehrigkeit;
	}  	

  /**
   * Innere Klasse zum Speichern der Werte eines Staukriterium.<p>
   * 
	 * Folgende Werte werden in dieser Klasse verwaltet:<br>
	 * - Vertrauenswrdigkeit<br>
	 * - Zugehrigkeit<br>
	 * - Gte<p>
	 * 
   * @version $Revision: 1.2 $ / $Date: 2012/07/23 06:02:35 $ / ($Author: Asal $)
   *
   * @author Swarco Traffic Systems GmbH
   * @author Rolf Asal
   *
   */
  private class StaukriteriumWerte
  {
  	/**
  	 * Vertrauenswrdigkeit.
  	 */
  	protected float vertrauenswrdigkeit = (float)0.0;
  	/**
  	 * Zugehrigkeit.
  	 */
  	protected float zugehrigkeit = (float)0.0;
  	/**
  	 * Gte.
  	 */
  	protected float gte = (float)0.0;

  	/* (non-Javadoc)
  	 * @see java.lang.Object#toString()
  	 */
  	public String toString()
  	{
  		StringBuffer string = new StringBuffer();
  		
  		string.append("Vetrauenswrdigkeit " +  vertrauenswrdigkeit +
  									" Zugehrigkeit " + zugehrigkeit +
  									" Gte " + gte);
  		
  		return string.toString();
  	}
  }
}
