/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Entwicklung
 * Adolf-Dambach-Strae
 * D-76571 Gaggenau
 * Phone: +49 (0)7225-64-0
 * Fax: +49 (0)7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.stau;

/**
 * Diese Klasse speichert die Inhalte fr die Zusammenfassung der Staukriterien.<p>
 * 
 * ber Getter und Setter kann auf die Daten zugegriffen werden.
 *
 * @version $Revision: 1.2 $ / $Date: 2012/07/23 06:02:35 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class StaukriteriumZusammenfassung
{
	/**
	 * Ergebnis der Auswertung der normierten Staukriterien.
	 */
	private String m_staukriterium;	
	/**
	 * Ergebnis der Zusammenfassung der Stauindikatoren fr den Zustand Nicht-Stau.
	 */
	private StaukriteriumWerte m_nichtStau;
	/**
	 * Ergebnis der Zusammenfassung der Stauindikatoren fr den Zustand Stau.
	 */
	private StaukriteriumWerte m_stau;

	/**
	 * Default-Konstruktor ohne weitere Funktion.
	 */
	public StaukriteriumZusammenfassung()
	{		
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() 
	{
		StringBuffer string = new StringBuffer();
		
		string.append("\n Staukriterium: " + m_staukriterium +
									"\n Nicht-Stau   : " + m_nichtStau +
				          "\n Stau         : " + m_stau);
		
		return string.toString();
  }


	/**
	 * Gibt das Ergebnis der Auswertung der normierten Staukriterien zurck.
	 * @return Ergebnis der Auswertung der normierten Staukriterien.
	 */
	public String getStaukriterium()
	{
		return m_staukriterium;
	}

	/**
	 * Setzt das Ergebnis der Auswertung der normierten Staukriterien.
	 * @param staukriterium zu setzendes Ergebnis der Auswertung der normierten Staukriterien.
	 */
	public void setStaukriterium(String staukriterium)
	{
		m_staukriterium = staukriterium;
	}

	/**
	 * Gibt das Ergebnis der Zusammenfassung der Stauindikatoren fr den Zustand Nicht-Stau zurck.
	 * @return Ergebnis der Zusammenfassung der Stauindikatoren fr den Zustand Nicht-Stau.
	 */
	public StaukriteriumWerte getNichtStau()
	{
		if (m_nichtStau == null)
			m_nichtStau = new StaukriteriumWerte();
		
		return m_nichtStau;
	}

	/**
	 * Setzt das Ergebnis der Zusammenfassung der Stauindikatoren fr den Zustand Nicht-Stau.
	 * @param nichtStau zu setzendes Ergebnis der Zusammenfassung der Stauindikatoren fr den Zustand Nicht-Stau.
	 */
	public void setNichtStau(StaukriteriumWerte nichtStau)
	{
		m_nichtStau = nichtStau;
	}

	/**
	 * Gibt das Ergebnis der Zusammenfassung der Stauindikatoren fr den Zustand Stau zurck.
	 * @return Ergebnis der Zusammenfassung der Stauindikatoren fr den Zustand Stau.
	 */
	public StaukriteriumWerte getStau()
	{
		if (m_stau == null)
			m_stau = new StaukriteriumWerte();
		
		return m_stau;
	}

	/**
	 * Setzt das Ergebnis der Zusammenfassung der Stauindikatoren fr den Zustand Stau.
	 * @param stau zu setzendes Ergebnis der Zusammenfassung der Stauindikatoren fr den Zustand Stau.
	 */
	public void setStau(StaukriteriumWerte stau)
	{
		m_stau = stau;
	}

	/**
	 * Innere Klasse zum Speichern der Zusammenfassung der Staukriterien.
	 *
	 * @version $Revision: 1.2 $ / $Date: 2012/07/23 06:02:35 $ / ($Author: Asal $)
	 *
	 * @author Swarco Traffic Systems GmbH
	 * @author Rolf Asal
	 *
	 */
	public class StaukriteriumWerte
	{
		/**
		 * Summe des Produkts aus Vertrauenswrdigkeit, Zugehrigkeit und Gte der Staukriterien 1 bis 5.
		 */
		private float m_p;
		/**
		 * Summe des Produkts normiert.
		 */
		private float m_pn;
		/**
		 * Gte der ermittelten Zusammenfassung.
		 */
		private float m_g;
		
		/**
		 * Default-Konstruktor ohne weitere Funktion.
		 */
		public StaukriteriumWerte()
		{			
		}
		
		/* (non-Javadoc)
		 * @see java.lang.Object#toString()
		 */
		@Override
		public String toString() 
		{
			StringBuffer string = new StringBuffer();
			
			string.append("P " + m_p +
										" Pn " + m_pn +
					          " G " + m_g);
			
			return string.toString();
	  }

		/**
		 * Gibt die Summe des Produkts aus Vertrauenswrdigkeit, Zugehrigkeit und Gte der Staukriterien 1 bis 5 zurck.
		 * @return Summe des Produkts.
		 */
		public float getP()
		{
			return m_p;
		}

		/**
		 * Setzt die Summe des Produkts aus Vertrauenswrdigkeit, Zugehrigkeit und Gte der Staukriterien 1 bis 5.
		 * @param p zu setzende Summe.
		 */
		public void setP(float p)
		{
			m_p = p;
		}

		/**
		 * Gibt die Summe des Produkts normiert zurck.
		 * @return Summe des Produkts normiert.
		 */
		public float getPn()
		{
			return m_pn;
		}

		/**
		 * Setzt die Summe des Produkts normiert.
		 * @param pn zu setzende Summe des Produkts normiert.
		 */
		public void setPn(float pn)
		{
			m_pn = pn;
		}

		/**
		 * Gibt die Gte der ermittelten Zusammenfassung zurck.
		 * @return Gte der ermittelten Zusammenfassung.
		 */
		public float getG()
		{
			return m_g;
		}

		/**
		 * Setzt die Gte der ermittelten Zusammenfassung.
		 * @param g zu setzende Gte der ermittelten Zusammenfassung.
		 */
		public void setG(float g)
		{
			m_g = g;
		}
	}
}
